macro_rules! histogram_start_measure {
($v:ident) => { ... };
($v:ident, $l:expr) => { ... };
}Expand description
Macro to start a timer measurement on a histogram.
macro_rules! histogram_start_measure {
($v:ident) => { ... };
($v:ident, $l:expr) => { ... };
}Macro to start a timer measurement on a histogram.